@@ -6,16 +6,28 @@ use std::collections::HashMap;
 use std::fs;
 use std::path::Path;
 use std::sync::Arc;
-#[cfg(not(test))]
 use std::sync::OnceLock;
 use std::time::Duration;
 use tokio::sync::Semaphore;
 use toml::Value as TomlValue;
 
+use crate::cache;
 use crate::cli;
 use crate::config;
 use crate::debug::{log, log_debug, log_error, FeludaResult, LogLevel};
 
+static GITHUB_TOKEN: OnceLock<Option<String>> = OnceLock::new();
+
+/// Set the GitHub API token for authenticated requests
+pub fn set_github_token(token: Option<String>) {
+    let _ = GITHUB_TOKEN.set(token);
+}
+
+/// Get the GitHub API token if set
+fn get_github_token() -> Option<&'static str> {
+    GITHUB_TOKEN.get().and_then(|t| t.as_deref())
+}
+
 /// License compatibility enum
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
 pub enum LicenseCompatibility {
@@ -152,7 +164,7 @@ impl LicenseInfo {
 }
 
 /// License Info structure for GitHub API data
-#[derive(Debug, serde::Deserialize, serde::Serialize)]
+#[derive(Debug, Clone, serde::Deserialize, serde::Serialize)]
 pub struct License {
     pub title: String,            // The full name of the license
     pub spdx_id: String,          // The SPDX identifier for the license
@@ -162,9 +174,29 @@ pub struct License {
 }
 
 /// Fetch license data from GitHub's official Licenses API
+/// Attempts to load from cache first, falls back to GitHub API if cache miss or stale
 pub fn fetch_licenses_from_github() -> FeludaResult<HashMap<String, License>> {
     log(LogLevel::Info, "Fetching licenses from GitHub Licenses API");
 
+    match cache::load_github_licenses_from_cache() {
+        Ok(Some(cached_licenses)) => {
+            log(
+                LogLevel::Info,
+                &format!("Using cached licenses ({})", cached_licenses.len()),
+            );
+            return Ok(cached_licenses);
+        }
+        Ok(None) => {
+            log(LogLevel::Info, "Cache miss or stale, fetching from GitHub");
+        }
+        Err(e) => {
+            log(
+                LogLevel::Warn,
+                &format!("Cache read error: {e}, fetching from GitHub"),
+            );
+        }
+    }
+
     let licenses_map = cli::with_spinner("Fetching licenses from GitHub API", |indicator| {
         // Use tokio runtime for async operations
         let rt = match tokio::runtime::Runtime::new() {
@@ -178,6 +210,17 @@ pub fn fetch_licenses_from_github() -> FeludaResult<HashMap<String, License>> {
         rt.block_on(fetch_licenses_concurrent(indicator))
     });
 
+    if !licenses_map.is_empty() {
+        if let Err(e) = cache::save_github_licenses_to_cache(&licenses_map) {
+            log(LogLevel::Warn, &format!("Failed to save cache: {e}"));
+        }
+    } else {
+        log(
+            LogLevel::Warn,
+            "No licenses fetched from GitHub API, cache not saved",
+        );
+    }
+
     Ok(licenses_map)
 }
 
@@ -187,12 +230,27 @@ async fn fetch_licenses_concurrent(
 ) -> HashMap<String, License> {
     let mut licenses_map = HashMap::new();
 
-    // Create async HTTP client
-    let client = match reqwest::Client::builder()
+    // Create async HTTP client with optional authentication
+    let mut client_builder = reqwest::Client::builder()
         .user_agent("feluda-license-checker/1.0")
-        .timeout(Duration::from_secs(30))
-        .build()
-    {
+        .timeout(Duration::from_secs(30));
+
+    if let Some(token) = get_github_token() {
+        log(
+            LogLevel::Info,
+            "Using authenticated GitHub API requests (higher rate limits)",
+        );
+        let mut headers = reqwest::header::HeaderMap::new();
+        headers.insert(
+            reqwest::header::AUTHORIZATION,
+            format!("Bearer {token}")
+                .parse()
+                .expect("Invalid token format"),
+        );
+        client_builder = client_builder.default_headers(headers);
+    }
+
+    let client = match client_builder.build() {
         Ok(client) => client,
         Err(err) => {
             log_error("Failed to create HTTP client", &err);
