@@ -3,16 +3,16 @@
 use crate::cli;
 use crate::debug::{log, log_debug, FeludaResult, LogLevel};
 use crate::languages::{
-    c::analyze_c_licenses, cpp::analyze_cpp_licenses, go::analyze_go_licenses,
-    node::analyze_js_licenses_with_no_local, python::analyze_python_licenses,
-    r::analyze_r_licenses, rust::analyze_rust_licenses_with_no_local,
+    c::analyze_c_licenses, cpp::analyze_cpp_licenses, dotnet::analyze_dotnet_licenses,
+    go::analyze_go_licenses, node::analyze_js_licenses_with_no_local,
+    python::analyze_python_licenses, r::analyze_r_licenses,
+    rust::analyze_rust_licenses_with_no_local,
 };
-use crate::languages::{Language, CPP_PATHS, C_PATHS, PYTHON_PATHS, R_PATHS};
+use crate::languages::{Language, CPP_PATHS, C_PATHS, DOTNET_PATHS, PYTHON_PATHS, R_PATHS};
 use crate::licenses::{
     detect_project_license, is_license_compatible, LicenseCompatibility, LicenseInfo,
 };
 use cargo_metadata::MetadataCommand;
-use ignore::Walk;
 use rayon::prelude::*;
 use std::path::{Path, PathBuf};
 
@@ -23,40 +23,30 @@ struct ProjectRoot {
     pub project_type: Language,
 }
 
-/// Walk through a directory and find all project-related roots
+/// Find project files only in the root directory (not recursive)
 fn find_project_roots(root_path: impl AsRef<Path>) -> FeludaResult<Vec<ProjectRoot>> {
     let mut project_roots = Vec::new();
+    let root = root_path.as_ref();
+
     log(
         LogLevel::Info,
-        &format!(
-            "Scanning for project files in: {}",
-            root_path.as_ref().display()
-        ),
+        &format!("Scanning for project files in: {}", root.display()),
     );
 
-    for entry in Walk::new(&root_path).filter_map(|e| match e {
-        Ok(entry) => Some(entry),
-        Err(err) => {
-            log(
-                LogLevel::Error,
-                &format!("Error while walking directory: {err}"),
-            );
-            None
-        }
-    }) {
-        if let Some(file_type) = entry.file_type() {
-            if !file_type.is_file() {
+    // Only check files directly in the root directory, don't recurse into subdirectories
+    if let Ok(entries) = std::fs::read_dir(root) {
+        for entry in entries.filter_map(|e| e.ok()) {
+            if let Ok(file_type) = entry.file_type() {
+                if !file_type.is_file() {
+                    continue;
+                }
+            } else {
                 continue;
             }
-        } else {
-            continue;
-        }
 
-        let path = entry.path();
-        let file_name = path.file_name().and_then(|n| n.to_str()).unwrap_or("");
-        let parent_path = path.parent();
+            let path = entry.path();
+            let file_name = path.file_name().and_then(|n| n.to_str()).unwrap_or("");
 
-        if let Some(parent) = parent_path {
             if let Some(project_type) = Language::from_file_name(file_name) {
                 log(
                     LogLevel::Info,
@@ -67,7 +57,7 @@ fn find_project_roots(root_path: impl AsRef<Path>) -> FeludaResult<Vec<ProjectRo
                     ),
                 );
                 project_roots.push(ProjectRoot {
-                    path: parent.to_path_buf(),
+                    path: root.to_path_buf(),
                     project_type,
                 });
             }
@@ -175,6 +165,44 @@ fn check_which_r_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
     None
 }
 
+fn check_which_dotnet_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
+    for &path in DOTNET_PATHS.iter() {
+        if path.starts_with('.') {
+            if let Ok(entries) = std::fs::read_dir(project_path.as_ref()) {
+                for entry in entries.filter_map(|e| e.ok()) {
+                    if let Some(file_name) = entry.file_name().to_str() {
+                        if file_name.ends_with(path) {
+                            log(
+                                LogLevel::Info,
+                                &format!("Found .NET project file: {}", entry.path().display()),
+                            );
+                            return Some(file_name.to_string());
+                        }
+                    }
+                }
+            }
+        } else {
+            let full_path = Path::new(project_path.as_ref()).join(path);
+            if full_path.exists() {
+                log(
+                    LogLevel::Info,
+                    &format!("Found .NET project file: {}", full_path.display()),
+                );
+                return Some(path.to_string());
+            }
+        }
+    }
+
+    log(
+        LogLevel::Warn,
+        &format!(
+            "No .NET project file found in: {}",
+            project_path.as_ref().display()
+        ),
+    );
+    None
+}
+
 /// Main entry point for parsing project dependencies
 pub fn parse_root(
     root_path: impl AsRef<Path>,
@@ -211,7 +239,7 @@ pub fn parse_root_with_config(
         );
         println!(
             "❌ No supported project files found.\n\
-            Feluda supports: C, C++, Rust, Node.js, Go, Python, R"
+            Feluda supports: C, C++, .NET, Rust, Node.js, Go, Python, R"
         );
         return Ok(Vec::new());
     }
@@ -327,6 +355,10 @@ fn matches_language(project_type: Language, language: &str) -> bool {
         (project_type, language.to_lowercase().as_str()),
         (Language::C(_), "c")
             | (Language::Cpp(_), "cpp" | "c++")
+            | (
+                Language::DotNet(_),
+                "dotnet" | ".net" | "csharp" | "c#" | "fsharp" | "f#"
+            )
             | (Language::Rust(_), "rust")
             | (Language::Node(_), "node")
             | (Language::Go(_), "go")
@@ -506,6 +538,34 @@ fn parse_dependencies(
                     Vec::new()
                 }
             },
+            Language::DotNet(_) => match check_which_dotnet_file_exists(project_path) {
+                Some(dotnet_project_file) => {
+                    let project_path = Path::new(project_path).join(&dotnet_project_file);
+                    log(
+                        LogLevel::Info,
+                        &format!("Parsing .NET project: {}", project_path.display()),
+                    );
+
+                    indicator.update_progress(&format!("analyzing {dotnet_project_file}"));
+
+                    match project_path.to_str() {
+                        Some(path_str) => {
+                            let deps = analyze_dotnet_licenses(path_str, config);
+                            indicator
+                                .update_progress(&format!("found {} dependencies", deps.len()));
+                            deps
+                        }
+                        None => {
+                            log(LogLevel::Error, "Failed to convert .NET path to string");
+                            Vec::new()
+                        }
+                    }
+                }
+                None => {
+                    log(LogLevel::Error, ".NET project file not found");
+                    Vec::new()
+                }
+            },
             Language::R(_) => match check_which_r_file_exists(project_path) {
                 Some(r_package_file) => {
                     let project_path = Path::new(project_path).join(&r_package_file);
@@ -721,11 +781,10 @@ mod tests {
         std::fs::write(root_path.join("go.mod"), "module test").unwrap();
 
         let result = find_project_roots(root_path.to_str().unwrap()).unwrap();
-        assert_eq!(result.len(), 3);
+        // Only finds go.mod in root directory (non-recursive scanning)
+        assert_eq!(result.len(), 1);
 
         let project_types: Vec<_> = result.iter().map(|r| r.project_type).collect();
-        assert!(project_types.contains(&Language::Rust("Cargo.toml")));
-        assert!(project_types.contains(&Language::Node("package.json")));
         assert!(project_types.contains(&Language::Go("go.mod")));
     }
 
