@@ -890,8 +890,10 @@ pub fn generate_spdx_output(
 #[cfg(test)]
 mod tests {
     use super::*;
+    use serial_test::serial;
 
     #[test]
+    #[serial]
     fn test_convert_to_spdx_license_expression() {
         // Ensure environment variable is not set
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
@@ -999,7 +1001,10 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_license_expression_edge_cases() {
+        std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
+
         // Test empty license
         assert_eq!(convert_to_spdx_license_expression(""), "NOASSERTION");
         assert_eq!(convert_to_spdx_license_expression("   "), "NOASSERTION");
@@ -1106,6 +1111,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_complex_package_names() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
         // Test the specific lodash.castarray case
@@ -1143,7 +1149,10 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_extreme_edge_case_packages() {
+        std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
+
         // Test package with only special characters
         let special_package = SpdxPackage::new("@#$%^&*()".to_string(), "https://example.com/test")
             .with_version("!!!".to_string())
@@ -1209,6 +1218,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_micromark_util_symbol_case() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
         // Test the specific case from the error message
@@ -1239,6 +1249,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_license_concluded_vs_declared() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
         // Test normal license handling
@@ -1321,7 +1332,10 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_ultra_conservative_license_validation() {
+        std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
+
         // Test the enhanced validation catches more edge cases
         assert_eq!(
             convert_to_spdx_license_expression("MIT=invalid"),
@@ -1406,6 +1420,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_force_noassertion_mode() {
         // Test normal mode first
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
@@ -1479,6 +1494,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_package_metadata_validation() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
 
@@ -1516,6 +1532,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_download_location_validation() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
 
@@ -1547,6 +1564,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_copyright_validation() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
 
@@ -1570,6 +1588,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_external_ref_validation() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
 
@@ -1602,6 +1621,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_comment_validation() {
         std::env::remove_var("FELUDA_FORCE_NOASSERTION_LICENSES");
 
